"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.preprocess = void 0;
const parser_1 = require("@babel/parser");
const traverse_1 = __importDefault(require("@babel/traverse"));
const printNodeWithBrackets_js_1 = require("./printNodeWithBrackets.js");
const getParseOptions = (isJsx) => ({
    sourceType: "module",
    allowImportExportEverywhere: true,
    allowReturnOutsideFunction: true,
    allowNewTargetOutsideFunction: true,
    allowSuperOutsideMethod: true,
    allowUndeclaredExports: true,
    errorRecovery: true,
    plugins: [
        "doExpressions",
        "exportDefaultFrom",
        "functionBind",
        "functionSent",
        "throwExpressions",
        "partialApplication",
        "decorators",
        "decimal",
        "moduleBlocks",
        "asyncDoExpressions",
        "regexpUnicodeSets",
        "destructuringPrivate",
        "decoratorAutoAccessors",
        "importReflection",
        "explicitResourceManagement",
        "decoratorAutoAccessors",
        "typescript",
        ...(isJsx ? ["jsx"] : []),
        ["importAttributes", { deprecatedAssertSyntax: true }],
    ],
});
function preprocess(code, options) {
    const ast = (0, parser_1.parse)(code, getParseOptions(/(?:js|x)$/.test(options.filepath)));
    const collectedNodes = [];
    function createCollector(property) {
        return ({ node, }) => {
            if (node[property].type !== "BlockStatement") {
                collectedNodes.push(node);
            }
        };
    }
    (0, traverse_1.default)(ast, {
        noScope: true,
        DoWhileStatement: createCollector("body"),
        ForInStatement: createCollector("body"),
        ForOfStatement: createCollector("body"),
        ForStatement: createCollector("body"),
        IfStatement: createCollector("consequent"),
        WhileStatement: createCollector("body"),
    });
    let output = "";
    let lastEnd = 0;
    /* eslint-disable @typescript-eslint/no-non-null-assertion */
    for (const collectedNode of collectedNodes) {
        output += code.slice(lastEnd, collectedNode.start);
        output += (0, printNodeWithBrackets_js_1.printNodeWithBrackets)(code, collectedNode);
        lastEnd = collectedNode.end;
    }
    /* eslint-enable @typescript-eslint/no-non-null-assertion */
    return output + code.slice(lastEnd);
}
exports.preprocess = preprocess;
//# sourceMappingURL=preprocess.js.map