"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const preprocess_js_1 = require("./preprocess.js");
(0, vitest_1.describe)("preprocess", () => {
    vitest_1.test.each([
        [`do a; while (b);`, `do { a; } while (b)`],
        [`do { a; } while (b);`, `do { a; } while (b);`],
        [`for (; ; ) d;`, `for (; ; ) { d; }`],
        [`for (; ; ) { d; }`, `for (; ; ) { d; }`],
        [`for (a; b; c) d;`, `for (a; b; c) { d; }`],
        [`for (a; b; c) { d; }`, `for (a; b; c) { d; }`],
        [`for (const a in b) c;`, `for (const a in b) { c; }`],
        [`for (const a in b) { c; }`, `for (const a in b) { c; }`],
        [`for (const a of b) c;`, `for (const a of b) { c; }`],
        [`for (const a of b) { c; }`, `for (const a of b) { c; }`],
        [`if (a) b;`, `if (a) { b; }`],
        [`if (a) { b; }`, `if (a) { b; }`],
        ["let a; let a;", "let a; let a;"],
        ["foo; import a from 'bar'", "foo; import a from 'bar'"],
        ["return;", "return;"],
        ["new.target;", "new.target;"],
        ["await 1;", "await 1;"],
        ["super;", "super;"],
        ["export { foo };", "export { foo };"],
        [`while (a) b;`, `while (a) { b; }`],
        [`while (a) { b; }`, `while (a) { b; }`],
        ["while (a) <b>c;", "while (a) { <b>c; }"],
        ["while (a) <b />;", "while (a) { <b />; }", "test.js"],
        ["while (a) <b />;", "while (a) { <b />; }", "test.tsx"],
    ])("%s becomes %s", (input, expected, filepath = "test.ts") => {
        (0, vitest_1.expect)((0, preprocess_js_1.preprocess)(input, { filepath })).toBe(expected);
    });
});
//# sourceMappingURL=preprocess.test.js.map